@@ -1,4 +1,5 @@
 from typing import List, Callable
+from .get_annotation_fn import crossval
 
 
 class GetAnnotationABC:
@@ -11,14 +12,18 @@ class GetAnnotationABC:
     get_train_fn: Callable[[str, str, str, List[str]], List[List[str]]]
 
     # for val annotation
-    img_dir_val: str
-    label_dir_val: str
+    img_dir_val: str = None
+    label_dir_val: str = None
     val_dirs: List[str] = None
-    get_val_fn: Callable[[str, str, str, List[str]], List[List[str]]]
+    get_val_fn: Callable[[str, str, str, List[str]], List[List[str]]] = None
 
     @classmethod
-    def __call__(cls):
-        return cls.get_train_annotations(), cls.get_val_annotations()
+    def __call__(cls, cv_fold: int = None, cv_i=0, depth=0):
+        if cv_fold:
+            print(f"cross_val: {cv_i+1}/{cv_fold}")
+            return crossval(cls.get_train_annotations(), cv_fold, cv_i, depth)
+        else:
+            return cls.get_train_annotations(), cls.get_val_annotations()
 
     @classmethod
     def get_train_annotations(cls):
@@ -29,6 +34,3 @@ class GetAnnotationABC:
     def get_val_annotations(cls):
         return cls.get_val_fn(
             cls.target, cls.img_dir_val, cls.label_dir_val, cls.val_dirs)
-
-    def __init__(self):
-        print("get annotation...")
